'use strict';

exports.__esModule = true;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

var _parserJs = require('./parser.js');

var _apiJs = require('./api.js');

var _apiJs2 = _interopRequireDefault(_apiJs);

var Posthtml = (function () {
    function Posthtml() {
        var plugins = arguments.length <= 0 || arguments[0] === undefined ? [] : arguments[0];

        _classCallCheck(this, Posthtml);

        this.plugins = plugins;
    }

    /**
     * Parse html to json tree
     * @param  {String} html htmltree
     * @return {String} json jsontree
     */

    Posthtml.prototype.parse = function parse(html) {
        return _parserJs.toTree(html);
    };

    /**
     * use plugins
     * @param  {function} plugin posthtml().use(plugin());
     */

    Posthtml.prototype.use = function use(plugin) {
        this.plugins.push(plugin);
        return this;
    };

    /**
     * @param  {String} tree  html/json tree
     * @param {Object} options Options obj
     * @return {Object}        result
     */

    Posthtml.prototype.process = function process(tree) {
        var _this = this;

        var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

        return new Promise(function (resolve) {

            tree = options.skipParse ? tree : _this.parse(tree);
            tree.options = options;

            for (var key in _apiJs2['default']) {
                tree[key] = _apiJs2['default'][key];
            }

            _this.plugins.forEach(function (plugin) {
                var result = plugin(tree);

                if (result) {
                    tree = result;
                }
            });

            resolve({
                html: _parserJs.toHtml(tree),
                tree: tree
            });
        });
    };

    return Posthtml;
})();

exports['default'] = function (plugins) {
    return new Posthtml(plugins);
};

module.exports = exports['default'];